InputMessage

Enum InputMessage 

pub enum InputMessage {
Show 15 variants Touch = 0, KeyPress = 1, KeyRelease = 2, NavigationFocused = 3, NavigationCancelled = 4, Noop = 5, Visible = 6, Hidden = 7, FrameBuffer = 8, Custom1 = 9, Custom2 = 10, Custom3 = 11, Custom4 = 12, CloseRequested = 13, Scroll = 14,
}

Variants



Touch = 0



KeyPress = 1



KeyRelease = 2



NavigationFocused = 3

Another app has navigated to this app, and the app is now in modal focus. This input message is a notification to check the GuiApi for a navigation event.



NavigationCancelled = 4

The app is being navigated away from and is no longer in modal focus.



Noop = 5

The apps that block on input can unblock themselves by sending this message to themselves.



Visible = 6

The app is brought into the foreground.



Hidden = 7

The app is getting minimized and hidden in the background.



FrameBuffer = 8

A new framebuffer the app can draw to. Can be the same as a previous buffer or a completely new one.



Custom1 = 9



Custom2 = 10



Custom3 = 11



Custom4 = 12



CloseRequested = 13

The app should exit gracefully after receiving this.



Scroll = 14

Mouse/trackpad scroll in the emulator (hosted mode only). Scalar args: arg1 = x (physical px), arg2 = y (physical px), arg3 = delta_x (f32 bits), arg4 = delta_y (f32 bits).