pub enum ModalStyle {
SlideUpDraggablePopup = 0,
SlideUpFixedPopup = 1,
SlideUpFullscreen = 2,
Instant = 3,
}Variants
SlideUpDraggablePopup = 0
A regular modal card that slides up from the bottom of the screen. The user can drag it and dismiss it by dragging or clicking away.
SlideUpFixedPopup = 1
A modal card that slides up from the bottom of the screen. The user can’t drag it and dismiss it by clicking away.
SlideUpFullscreen = 2
A modal card that slides up from the bottom of the screen and takes the entire screen.
Instant = 3
A modal that appears instantly with no animation.