pub enum RunAppResponse {
Launched {
pid: usize,
},
AlreadyRunning {
pid: usize,
},
Locked,
NotReady,
AppIdNotFound,
LaunchFailed {
reason: LaunchFailureReason,
},
}Variants
Launched
AlreadyRunning
Locked
NotReady
AppIdNotFound
LaunchFailed
Fields

reason: LaunchFailureReasonTrait Implementations
Sourceimpl Archive for RunAppResponsewhere
usize: Archive,
LaunchFailureReason: Archive,
impl Archive for RunAppResponsewhere
usize: Archive,
LaunchFailureReason: Archive,
Sourcetype Archived = ArchivedRunAppResponse
type Archived = ArchivedRunAppResponse
The archived representation of this type. Read more
Sourcetype Resolver = RunAppResponseResolver
type Resolver = RunAppResponseResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(
&self,
resolver: <Self as Archive>::Resolver,
out: Place<<Self as Archive>::Archived>,
)
fn resolve( &self, resolver: <Self as Archive>::Resolver, out: Place<<Self as Archive>::Archived>, )
Creates the archived version of this value at the given position and
writes it to the given output. Read more
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl Clone for RunAppResponse
impl Clone for RunAppResponse
Sourcefn clone(&self) -> RunAppResponse
fn clone(&self) -> RunAppResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RunAppResponse
impl Debug for RunAppResponse
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RunAppResponse, __D> for Archived<RunAppResponse>where
usize: Archive,
<usize as Archive>::Archived: Deserialize<usize, __D>,
LaunchFailureReason: Archive,
<LaunchFailureReason as Archive>::Archived: Deserialize<LaunchFailureReason, __D>,
impl<__D: Fallible + ?Sized> Deserialize<RunAppResponse, __D> for Archived<RunAppResponse>where
usize: Archive,
<usize as Archive>::Archived: Deserialize<usize, __D>,
LaunchFailureReason: Archive,
<LaunchFailureReason as Archive>::Archived: Deserialize<LaunchFailureReason, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RunAppResponse, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RunAppResponse, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for RunAppResponse
impl PartialEq for RunAppResponse
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for RunAppResponsewhere
usize: Serialize<__S>,
LaunchFailureReason: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for RunAppResponsewhere
usize: Serialize<__S>,
LaunchFailureReason: Serialize<__S>,
impl Eq for RunAppResponse
impl StructuralPartialEq for RunAppResponse