pub struct NavigateTo {
pub app_id: AppId,
pub args: Vec<u8>,
}Fields
app_id: AppIdargs: Vec<u8>Trait Implementations
Sourcetype Archived = ArchivedNavigateTo
type Archived = ArchivedNavigateTo
The archived representation of this type. Read more
Sourcetype Resolver = NavigateToResolver
type Resolver = NavigateToResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Response = Result<FinishResponse, NavigationError>
type Response = Result<FinishResponse, NavigationError>
response type for this message
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<NavigateTo, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<NavigateTo, <__D as Fallible>::Error>
Deserializes using the given deserializer