pub struct RegisterAppMessage(pub RegisterApp);Tuple Fields
0: RegisterAppTrait Implementations
Sourceimpl Archive for RegisterAppMessagewhere
RegisterApp: Archive,
impl Archive for RegisterAppMessagewhere
RegisterApp: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRegisterAppMessage
type Archived = ArchivedRegisterAppMessage
The archived representation of this type. Read more
Sourcetype Resolver = RegisterAppMessageResolver
type Resolver = RegisterAppMessageResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for RegisterAppMessage
impl BlockingArchive for RegisterAppMessage
Sourceimpl Debug for RegisterAppMessage
impl Debug for RegisterAppMessage
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RegisterAppMessage, __D> for Archived<RegisterAppMessage>
impl<__D: Fallible + ?Sized> Deserialize<RegisterAppMessage, __D> for Archived<RegisterAppMessage>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RegisterAppMessage, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RegisterAppMessage, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for RegisterAppMessage
impl MessageId for RegisterAppMessage
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for RegisterAppMessagewhere
RegisterApp: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for RegisterAppMessagewhere
RegisterApp: Serialize<__S>,