pub struct RegisterControlCenter {
pub cid: CID,
pub height: usize,
}Fields
cid: CIDheight: usizeTrait Implementations
Sourceimpl Archive for RegisterControlCenterwhere
CID: Archive,
usize: Archive,
impl Archive for RegisterControlCenterwhere
CID: Archive,
usize: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRegisterControlCenter
type Archived = ArchivedRegisterControlCenter
The archived representation of this type. Read more
Sourcetype Resolver = RegisterControlCenterResolver
type Resolver = RegisterControlCenterResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for RegisterControlCenter
impl BlockingArchive for RegisterControlCenter
Sourcetype Response = Result<(), GuiServerError>
type Response = Result<(), GuiServerError>
response type for this message
Sourceimpl Debug for RegisterControlCenter
impl Debug for RegisterControlCenter
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RegisterControlCenter, __D> for Archived<RegisterControlCenter>where
CID: Archive,
<CID as Archive>::Archived: Deserialize<CID, __D>,
usize: Archive,
<usize as Archive>::Archived: Deserialize<usize, __D>,
impl<__D: Fallible + ?Sized> Deserialize<RegisterControlCenter, __D> for Archived<RegisterControlCenter>where
CID: Archive,
<CID as Archive>::Archived: Deserialize<CID, __D>,
usize: Archive,
<usize as Archive>::Archived: Deserialize<usize, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RegisterControlCenter, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RegisterControlCenter, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for RegisterControlCenter
impl MessageId for RegisterControlCenter
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for RegisterControlCenterwhere
CID: Serialize<__S>,
usize: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for RegisterControlCenterwhere
CID: Serialize<__S>,
usize: Serialize<__S>,