pub struct ShowModal {
pub modal_style: ModalStyle,
pub app_id: AppId,
pub args: Vec<u8>,
}Fields
modal_style: ModalStyleapp_id: AppIdargs: Vec<u8>Trait Implementations
Sourceimpl Archive for ShowModal
impl Archive for ShowModal
Sourcetype Archived = ArchivedShowModal
type Archived = ArchivedShowModal
The archived representation of this type. Read more
Sourcetype Resolver = ShowModalResolver
type Resolver = ShowModalResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl BlockingArchive for ShowModal
impl BlockingArchive for ShowModal
Sourcetype Response = Result<FinishResponse, NavigationError>
type Response = Result<FinishResponse, NavigationError>
response type for this message
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ShowModal, __D> for Archived<ShowModal>where
ModalStyle: Archive,
<ModalStyle as Archive>::Archived: Deserialize<ModalStyle, __D>,
WithAppId: ArchiveWith<AppId> + DeserializeWith<<WithAppId as ArchiveWith<AppId>>::Archived, AppId, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ShowModal, __D> for Archived<ShowModal>where
ModalStyle: Archive,
<ModalStyle as Archive>::Archived: Deserialize<ModalStyle, __D>,
WithAppId: ArchiveWith<AppId> + DeserializeWith<<WithAppId as ArchiveWith<AppId>>::Archived, AppId, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,