pub struct UpdateKeyboard {
pub kind: KeyboardKind,
pub request_caps: bool,
pub accept_button_text: String,
pub accept_button_enabled: bool,
pub delete_button_enabled: bool,
}Fields
kind: KeyboardKindrequest_caps: boolTrait Implementations
Sourceimpl Archive for UpdateKeyboard
impl Archive for UpdateKeyboard
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedUpdateKeyboard
type Archived = ArchivedUpdateKeyboard
The archived representation of this type. Read more
Sourcetype Resolver = UpdateKeyboardResolver
type Resolver = UpdateKeyboardResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for UpdateKeyboard
impl Debug for UpdateKeyboard
Sourceimpl<__D: Fallible + ?Sized> Deserialize<UpdateKeyboard, __D> for Archived<UpdateKeyboard>where
KeyboardKind: Archive,
<KeyboardKind as Archive>::Archived: Deserialize<KeyboardKind, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
impl<__D: Fallible + ?Sized> Deserialize<UpdateKeyboard, __D> for Archived<UpdateKeyboard>where
KeyboardKind: Archive,
<KeyboardKind as Archive>::Archived: Deserialize<KeyboardKind, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<UpdateKeyboard, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<UpdateKeyboard, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for UpdateKeyboard
impl MessageId for UpdateKeyboard
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for UpdateKeyboard
impl<__S: Fallible + ?Sized> Serialize<__S> for UpdateKeyboard
impl Archive for UpdateKeyboard