pub struct ScanQrMatchedRule {
pub rule_id: String,
pub priority: QrPriority,
pub sub_rule_id: String,
}Expand description
Options for the QR Scanner navigation request.
Example with a left back arrow and a simple message:
ⓘ
let options = ScanQrOptions::default()
.with_start_location(Location::External)
.with_allowed_locations(AllowedLocations::specific(&[Location::External]))
.with_allowed_extensions(AllowedExtensions::specific(&["bin"]));A single rule (and the first sub-rule that triggered it) that matched a scanned QR code.
Fields
rule_id: Stringpriority: QrPrioritysub_rule_id: StringThe ID of the first sub-rule that matched — used for dispatch hints without bloating the message with every matching sub-rule.