pub struct CaptureScreen(pub MemoryRange);Expand description
Captures the current composited screen contents as raw pixel data.
On hardware the byte order is BGRA8888; on the simulator it is RGBA8888. Caller allocates a MemoryRange of SCREEN_WIDTH * SCREEN_HEIGHT * 4 bytes, lends it mutable to gui-server, which fills it with the composited pixel data.
Tuple Fields
0: MemoryRangeTrait Implementations
Sourceimpl Debug for CaptureScreen
impl Debug for CaptureScreen
Sourceimpl From<CaptureScreen> for SimpleMemoryMessage
impl From<CaptureScreen> for SimpleMemoryMessage
Sourcefn from(val: CaptureScreen) -> Self
fn from(val: CaptureScreen) -> Self
Converts to this type from the input type.
Sourceimpl From<SimpleMemoryMessage> for CaptureScreen
impl From<SimpleMemoryMessage> for CaptureScreen
Sourcefn from(value: SimpleMemoryMessage) -> Self
fn from(value: SimpleMemoryMessage) -> Self
Converts to this type from the input type.