pub struct ScanQrMatchingApp {
pub id: AppId,
pub matched_rules: Vec<ScanQrMatchedRule>,
}Expand description
One entry per app that has at least one matching rule for the scanned QR code. All matched rules for that app are collected here so the same app never appears more than once in the disambiguation list.
Fields
id: AppIdmatched_rules: Vec<ScanQrMatchedRule>Trait Implementations
Sourceimpl Archive for ScanQrMatchingApp
impl Archive for ScanQrMatchingApp
Sourcetype Archived = ArchivedScanQrMatchingApp
type Archived = ArchivedScanQrMatchingApp
The archived representation of this type. Read more
Sourcetype Resolver = ScanQrMatchingAppResolver
type Resolver = ScanQrMatchingAppResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl Clone for ScanQrMatchingApp
impl Clone for ScanQrMatchingApp
Sourcefn clone(&self) -> ScanQrMatchingApp
fn clone(&self) -> ScanQrMatchingApp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScanQrMatchingApp
impl Debug for ScanQrMatchingApp
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ScanQrMatchingApp, __D> for Archived<ScanQrMatchingApp>where
WithAppId: ArchiveWith<AppId> + DeserializeWith<<WithAppId as ArchiveWith<AppId>>::Archived, AppId, __D>,
Vec<ScanQrMatchedRule>: Archive,
<Vec<ScanQrMatchedRule> as Archive>::Archived: Deserialize<Vec<ScanQrMatchedRule>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ScanQrMatchingApp, __D> for Archived<ScanQrMatchingApp>where
WithAppId: ArchiveWith<AppId> + DeserializeWith<<WithAppId as ArchiveWith<AppId>>::Archived, AppId, __D>,
Vec<ScanQrMatchedRule>: Archive,
<Vec<ScanQrMatchedRule> as Archive>::Archived: Deserialize<Vec<ScanQrMatchedRule>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ScanQrMatchingApp, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ScanQrMatchingApp, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for ScanQrMatchingApp
impl<__S: Fallible + ?Sized> Serialize<__S> for ScanQrMatchingApp