pub struct GuiApi<P: CheckedPermissions> { /* private fields */ }Expand description
Full GUI API, usable by GUI apps
Implementations
Sourceimpl<P: CheckedPermissions> GuiApi<P>
impl<P: CheckedPermissions> GuiApi<P>
Sourceimpl<P: CheckedPermissions> GuiApi<P>
impl<P: CheckedPermissions> GuiApi<P>
Sourcepub fn register(name: &str, height: usize) -> Result<Self, GuiServerError>where
P: MessageAllowed<RegisterAppMessage>,
pub fn register(name: &str, height: usize) -> Result<Self, GuiServerError>where
P: MessageAllowed<RegisterAppMessage>,
Registers an ordinary app window.
Sourcepub fn set_control_center_color(
&self,
color: Option<ControlCenterColor>,
) -> Result<(), GuiServerError>where
P: MessageAllowed<SetControlCenterColor>,
pub fn set_control_center_color(
&self,
color: Option<ControlCenterColor>,
) -> Result<(), GuiServerError>where
P: MessageAllowed<SetControlCenterColor>,
Requests a background color for the collapsed Control Center while this app is visible.
Passing None restores the system theme color
pub fn sid(&self) -> SID
Sourcepub fn submit_frame(&self, buffer: MemoryRange) -> Result<(), GuiServerError>where
P: MessageAllowed<SubmitFrame>,
pub fn submit_frame(&self, buffer: MemoryRange) -> Result<(), GuiServerError>where
P: MessageAllowed<SubmitFrame>,
Submit a frame for display.
pub fn show_camera(&self, y_pos: u16) -> Result<(), GuiServerError>where
P: MessageAllowed<ShowCamera>,
pub fn hide_camera(&self) -> Result<(), GuiServerError>where
P: MessageAllowed<HideCamera>,
pub fn update_keyboard(&self, msg: UpdateKeyboard) -> Result<(), GuiServerError>where
P: MessageAllowed<UpdateKeyboard>,
pub fn hide_keyboard(&self) -> Result<(), GuiServerError>where
P: MessageAllowed<HideKeyboard>,
pub fn wake_event_loop(&self)
pub fn request_redraw(&self) -> Result<(), GuiServerError>where
P: MessageAllowed<RequestRedraw>,
pub fn try_receive_input(&self) -> Option<(InputMessage, MessageEnvelope)>
pub fn receive_input( &self, ) -> Result<(InputMessage, MessageEnvelope), GuiServerError>
pub fn animate_next_frame(
&self,
animation_kind: NextFrameAnimationKind,
) -> Result<(), GuiServerError>where
P: MessageAllowed<AnimateNextFrame>,
Methods from Deref<Target = GuiApiLight<P>>
Sourcepub fn show_modal(
&self,
app_id: AppId,
modal_style: ModalStyle,
args: &[u8],
) -> Result<NavigationResult, GuiServerError>where
P: MessageAllowed<ShowModal>,
pub fn show_modal(
&self,
app_id: AppId,
modal_style: ModalStyle,
args: &[u8],
) -> Result<NavigationResult, GuiServerError>where
P: MessageAllowed<ShowModal>,
Shows a modal of the app, giving it a navigation object
pub fn invoke_alert(
&self,
alert: InvokeAlert,
) -> Result<AlertResult, GuiServerError>where
P: MessageAllowed<ShowModal>,